@@ -28,7 +28,7 @@ class StackResourceDTO:
         # FIXME: None of these attributes are part of CloudFormationModel interface...
         self.logical_resource_id = getattr(resource, "logical_resource_id", None)
         self.physical_resource_id = getattr(resource, "physical_resource_id", None)
-        self.resource_type = getattr(resource, "resource_type", None)
+        self.resource_type = getattr(resource, "cf_resource_type", None)
         self.stack_status = stack.status
         self.creation_time = stack.creation_time
         self.timestamp = "2010-07-27T22:27:28Z"  # Hardcoded in original XML template.
@@ -325,8 +325,9 @@ class CloudFormationResponse(BaseResponse):
 
     def describe_stack_resources(self) -> ActionResult:
         stack_name = self._get_param("StackName")
+        logical_resource_id = self._get_param("LogicalResourceId")
         stack, resources = self.cloudformation_backend.describe_stack_resources(
-            stack_name
+            stack_name, logical_resource_id
         )
 
         result = {
@@ -365,7 +366,7 @@ class CloudFormationResponse(BaseResponse):
                     "LogicalResourceId": getattr(resource, "logical_resource_id", ""),
                     "LastUpdateTimestamp": "2011-06-21T20:15:58Z",
                     "PhysicalResourceId": getattr(resource, "physical_resource_id", ""),
-                    "ResourceType": getattr(resource, "resource_type", ""),
+                    "ResourceType": getattr(resource, "cf_resource_type", ""),
                 }
                 for resource in resources
             ]
