@@ -1,8 +1,10 @@
-from typing import Dict, List, Optional
+from typing import Dict, Optional
 
-from moto.core import BackendDict, BaseBackend, BaseModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 from moto.core.utils import iso_8601_datetime_with_milliseconds
 from moto.moto_api._internal import mock_random
+from moto.utilities.utils import get_partition
 
 from .exceptions import RepositoryDoesNotExistException, RepositoryNameExistsException
 
@@ -18,19 +20,19 @@ class CodeCommit(BaseModel):
         current_date = iso_8601_datetime_with_milliseconds()
         self.repository_metadata = dict()
         self.repository_metadata["repositoryName"] = repository_name
-        self.repository_metadata[
-            "cloneUrlSsh"
-        ] = f"ssh://git-codecommit.{region}.amazonaws.com/v1/repos/{repository_name}"
-        self.repository_metadata[
-            "cloneUrlHttp"
-        ] = f"https://git-codecommit.{region}.amazonaws.com/v1/repos/{repository_name}"
+        self.repository_metadata["cloneUrlSsh"] = (
+            f"ssh://git-codecommit.{region}.amazonaws.com/v1/repos/{repository_name}"
+        )
+        self.repository_metadata["cloneUrlHttp"] = (
+            f"https://git-codecommit.{region}.amazonaws.com/v1/repos/{repository_name}"
+        )
         self.repository_metadata["creationDate"] = current_date
         self.repository_metadata["lastModifiedDate"] = current_date
         self.repository_metadata["repositoryDescription"] = repository_description
         self.repository_metadata["repositoryId"] = str(mock_random.uuid4())
-        self.repository_metadata[
-            "Arn"
-        ] = f"arn:aws:codecommit:{region}:{account_id}:{repository_name}"
+        self.repository_metadata["Arn"] = (
+            f"arn:{get_partition(region)}:codecommit:{region}:{account_id}:{repository_name}"
+        )
         self.repository_metadata["accountId"] = account_id
 
 
@@ -39,15 +41,6 @@ class CodeCommitBackend(BaseBackend):
         super().__init__(region_name, account_id)
         self.repositories: Dict[str, CodeCommit] = {}
 
-    @staticmethod
-    def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
-        """Default VPC endpoint service."""
-        return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "codecommit"
-        )
-
     def create_repository(
         self, repository_name: str, repository_description: str
     ) -> Dict[str, str]:
