@@ -778,6 +778,16 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
             return int(val)
         return if_none
 
+    def _get_float_param(
+        self,
+        param_name: str,
+        if_none: TYPE_IF_NONE = None,  # type: ignore[assignment]
+    ) -> Union[float, TYPE_IF_NONE]:
+        val = self._get_param(param_name)
+        if val is not None:
+            return float(val)
+        return if_none
+
     def _get_bool_param(
         self,
         param_name: str,
