@@ -1,8 +1,9 @@
-from datetime import datetime
+from typing import Any, Dict, List, Optional, Tuple
 
-from moto.core import BaseBackend
-from moto.core.utils import iso_8601_datetime_without_milliseconds, BackendDict
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.utils import utcnow
 from moto.moto_api._internal import mock_random as random
+from moto.utilities.utils import get_partition
 
 from .exceptions import (
     InvalidParameterException,
@@ -10,7 +11,7 @@ from .exceptions import (
     ResourceInUseException,
     ResourceNotFoundException,
 )
-from .utils import get_partition, validate_role_arn
+from .utils import validate_role_arn
 
 # String Templates
 CLUSTER_ARN_TEMPLATE = "arn:{partition}:eks:{region}:{account_id}:cluster/{name}"
@@ -52,7 +53,7 @@ DEFAULT_AMI_TYPE = "AL2_x86_64"
 DEFAULT_CAPACITY_TYPE = "ON_DEMAND"
 DEFAULT_DISK_SIZE = "20"
 DEFAULT_INSTANCE_TYPES = ["t3.medium"]
-DEFAULT_NODEGROUP_HEALTH = {"issues": []}
+DEFAULT_NODEGROUP_HEALTH: Dict[str, Any] = {"issues": []}
 DEFAULT_RELEASE_VERSION = "1.19.8-20210414"
 DEFAULT_REMOTE_ACCESS = {"ec2SshKey": "eksKeypair"}
 DEFAULT_SCALING_CONFIG = {"minSize": 2, "maxSize": 2, "desiredSize": 2}
@@ -91,28 +92,29 @@ NODEGROUP_NOT_FOUND_MSG = "No node group found for name: {nodegroupName}."
 class Cluster:
     def __init__(
         self,
-        name,
-        role_arn,
-        resources_vpc_config,
-        account_id,
-        region_name,
-        aws_partition,
-        version=None,
-        kubernetes_network_config=None,
-        logging=None,
-        client_request_token=None,
-        tags=None,
-        encryption_config=None,
+        name: str,
+        role_arn: str,
+        resources_vpc_config: Dict[str, Any],
+        account_id: str,
+        region_name: str,
+        aws_partition: str,
+        version: Optional[str] = None,
+        kubernetes_network_config: Optional[Dict[str, str]] = None,
+        logging: Optional[Dict[str, Any]] = None,
+        client_request_token: Optional[str] = None,
+        tags: Optional[Dict[str, str]] = None,
+        encryption_config: Optional[List[Dict[str, Any]]] = None,
+        remote_network_config: Optional[Dict[str, List[Dict[str, List[str]]]]] = None,
     ):
         if encryption_config is None:
             encryption_config = []
         if tags is None:
             tags = dict()
 
-        self.nodegroups = dict()
+        self.nodegroups: Dict[str, Nodegroup] = dict()
         self.nodegroup_count = 0
 
-        self.fargate_profiles = dict()
+        self.fargate_profiles: Dict[str, FargateProfile] = dict()
         self.fargate_profile_count = 0
 
         self.arn = CLUSTER_ARN_TEMPLATE.format(
@@ -121,8 +123,8 @@ class Cluster:
             region=region_name,
             name=name,
         )
-        self.certificateAuthority = {"data": random.get_random_string(1400)}
-        self.creation_date = iso_8601_datetime_without_milliseconds(datetime.now())
+        self.certificate_authority = {"data": random.get_random_string(1400)}
+        self.created_at = utcnow()
         self.identity = {"oidc": {"issuer": ISSUER_TEMPLATE.format(region=region_name)}}
         self.endpoint = ENDPOINT_TEMPLATE.format(region=region_name)
 
@@ -140,49 +142,33 @@ class Cluster:
         self.resources_vpc_config = resources_vpc_config
         self.role_arn = role_arn
         self.tags = tags
+        self.remote_network_config = remote_network_config
 
-    def __iter__(self):
-        yield "name", self.name
-        yield "arn", self.arn
-        yield "createdAt", self.creation_date
-        yield "version", self.version
-        yield "endpoint", self.endpoint
-        yield "roleArn", self.role_arn
-        yield "resourcesVpcConfig", self.resources_vpc_config
-        yield "kubernetesNetworkConfig", self.kubernetes_network_config
-        yield "logging", self.logging
-        yield "identity", self.identity
-        yield "status", self.status
-        yield "certificateAuthority", self.certificateAuthority
-        yield "clientRequestToken", self.client_request_token
-        yield "platformVersion", self.platformVersion
-        yield "tags", self.tags
-        yield "encryptionConfig", self.encryption_config
-
-    def isActive(self):
+    @property
+    def is_active(self) -> bool:
         return self.status == "ACTIVE"
 
 
 class FargateProfile:
     def __init__(
         self,
-        cluster_name,
-        fargate_profile_name,
-        pod_execution_role_arn,
-        selectors,
-        account_id,
-        region_name,
-        aws_partition,
-        client_request_token=None,
-        subnets=None,
-        tags=None,
+        cluster_name: str,
+        fargate_profile_name: str,
+        pod_execution_role_arn: str,
+        selectors: List[Dict[str, Any]],
+        account_id: str,
+        region_name: str,
+        aws_partition: str,
+        client_request_token: Optional[str] = None,
+        subnets: Optional[List[str]] = None,
+        tags: Optional[Dict[str, str]] = None,
     ):
         if subnets is None:
             subnets = list()
         if tags is None:
             tags = dict()
 
-        self.created_at = iso_8601_datetime_without_milliseconds(datetime.now())
+        self.created_at = utcnow()
         self.uuid = str(random.uuid4())
         self.fargate_profile_arn = FARGATE_PROFILE_ARN_TEMPLATE.format(
             partition=aws_partition,
@@ -202,48 +188,37 @@ class FargateProfile:
         self.subnets = subnets
         self.tags = tags
 
-    def __iter__(self):
-        yield "clusterName", self.cluster_name
-        yield "createdAt", self.created_at
-        yield "fargateProfileArn", self.fargate_profile_arn
-        yield "fargateProfileName", self.fargate_profile_name
-        yield "podExecutionRoleArn", self.pod_execution_role_arn
-        yield "selectors", self.selectors
-        yield "subnets", self.subnets
-        yield "status", self.status
-        yield "tags", self.tags
 
-
-class ManagedNodegroup:
+class Nodegroup:
     def __init__(
         self,
-        cluster_name,
-        node_role,
-        nodegroup_name,
-        subnets,
-        account_id,
-        region_name,
-        aws_partition,
-        scaling_config=None,
-        disk_size=None,
-        instance_types=None,
-        ami_type=None,
-        remote_access=None,
-        labels=None,
-        taints=None,
-        tags=None,
-        client_request_token=None,
-        launch_template=None,
-        capacity_type=None,
-        version=None,
-        release_version=None,
+        cluster_name: str,
+        node_role: str,
+        nodegroup_name: str,
+        subnets: List[str],
+        account_id: str,
+        region_name: str,
+        aws_partition: str,
+        scaling_config: Optional[Dict[str, int]] = None,
+        disk_size: Optional[int] = None,
+        instance_types: Optional[List[str]] = None,
+        ami_type: Optional[str] = None,
+        remote_access: Optional[Dict[str, Any]] = None,
+        labels: Optional[Dict[str, str]] = None,
+        taints: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[Dict[str, str]] = None,
+        client_request_token: Optional[str] = None,
+        launch_template: Optional[Dict[str, str]] = None,
+        capacity_type: Optional[str] = None,
+        version: Optional[str] = None,
+        release_version: Optional[str] = None,
     ):
         if tags is None:
             tags = dict()
         if labels is None:
             labels = dict()
         if taints is None:
-            taints = dict()
+            taints = []
 
         self.uuid = str(random.uuid4())
         self.arn = NODEGROUP_ARN_TEMPLATE.format(
@@ -254,8 +229,8 @@ class ManagedNodegroup:
             nodegroup_name=nodegroup_name,
             uuid=self.uuid,
         )
-        self.creation_date = iso_8601_datetime_without_milliseconds(datetime.now())
-        self.modified_date = iso_8601_datetime_without_milliseconds(datetime.now())
+        self.created_at = utcnow()
+        self.modified_at = utcnow()
         self.health = DEFAULT_NODEGROUP_HEALTH
         self.resources = {
             "autoScalingGroups": [{"name": "eks-" + self.uuid}],
@@ -284,50 +259,46 @@ class ManagedNodegroup:
         self.tags = tags
         self.taints = taints
 
-    def __iter__(self):
-        yield "nodegroupName", self.nodegroup_name
-        yield "nodegroupArn", self.arn
-        yield "clusterName", self.cluster_name
-        yield "version", self.version
-        yield "releaseVersion", self.release_version
-        yield "createdAt", self.creation_date
-        yield "modifiedAt", self.modified_date
-        yield "status", self.status
-        yield "capacityType", self.capacity_type
-        yield "scalingConfig", self.scaling_config
-        yield "instanceTypes", self.instance_types
-        yield "subnets", self.subnets
-        yield "remoteAccess", self.remote_access
-        yield "amiType", self.ami_type
-        yield "nodeRole", self.node_role
-        yield "labels", self.labels
-        yield "taints", self.taints
-        yield "resources", self.resources
-        yield "diskSize", self.disk_size
-        yield "health", self.health
-        yield "launchTemplate", self.launch_template
-        yield "tags", self.tags
+        # Determine LaunchTemplateId from Name (and vice versa)
+        try:
+            from moto.ec2.models import ec2_backends
+
+            ec2 = ec2_backends[account_id][region_name]
+
+            template = None
+            if "name" in self.launch_template:  # type: ignore
+                name = self.launch_template["name"]  # type: ignore
+                template = ec2.describe_launch_templates(template_names=[name])[0]
+            elif "id" in self.launch_template:  # type: ignore
+                _id = self.launch_template["id"]  # type: ignore
+                template = ec2.describe_launch_templates(template_ids=[_id])[0]
+
+            self.launch_template["id"] = template.id  # type: ignore
+            self.launch_template["name"] = template.name  # type: ignore
+        except:  # noqa: E722 Do not use bare except
+            pass
 
 
 class EKSBackend(BaseBackend):
-    def __init__(self, region_name, account_id):
+    def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.clusters = dict()
+        self.clusters: Dict[str, Cluster] = dict()
         self.cluster_count = 0
         self.partition = get_partition(region_name)
 
     def create_cluster(
         self,
-        name,
-        role_arn,
-        resources_vpc_config,
-        version=None,
-        kubernetes_network_config=None,
-        logging=None,
-        client_request_token=None,
-        tags=None,
-        encryption_config=None,
-    ):
+        name: str,
+        role_arn: str,
+        resources_vpc_config: Dict[str, Any],
+        version: Optional[str] = None,
+        kubernetes_network_config: Optional[Dict[str, str]] = None,
+        logging: Optional[Dict[str, Any]] = None,
+        client_request_token: Optional[str] = None,
+        tags: Optional[Dict[str, str]] = None,
+        encryption_config: Optional[List[Dict[str, Any]]] = None,
+        remote_network_config: Optional[Dict[str, List[Dict[str, List[str]]]]] = None,
+    ) -> Cluster:
         if name in self.clusters:
             # Cluster exists.
             raise ResourceInUseException(
@@ -348,6 +319,7 @@ class EKSBackend(BaseBackend):
             client_request_token=client_request_token,
             tags=tags,
             encryption_config=encryption_config,
+            remote_network_config=remote_network_config,
             account_id=self.account_id,
             region_name=self.region_name,
             aws_partition=self.partition,
@@ -358,14 +330,14 @@ class EKSBackend(BaseBackend):
 
     def create_fargate_profile(
         self,
-        fargate_profile_name,
-        cluster_name,
-        selectors,
-        pod_execution_role_arn,
-        subnets=None,
-        client_request_token=None,
-        tags=None,
-    ):
+        fargate_profile_name: str,
+        cluster_name: str,
+        selectors: List[Dict[str, Any]],
+        pod_execution_role_arn: str,
+        subnets: Optional[List[str]] = None,
+        client_request_token: Optional[str] = None,
+        tags: Optional[Dict[str, str]] = None,
+    ) -> FargateProfile:
         try:
             # Cluster exists.
             cluster = self.clusters[cluster_name]
@@ -386,7 +358,7 @@ class EKSBackend(BaseBackend):
                 addonName=None,
                 message=FARGATE_PROFILE_EXISTS_MSG,
             )
-        if not cluster.isActive():
+        if not cluster.is_active:
             raise InvalidRequestException(
                 message=CLUSTER_NOT_READY_MSG.format(clusterName=cluster_name)
             )
@@ -412,24 +384,24 @@ class EKSBackend(BaseBackend):
 
     def create_nodegroup(
         self,
-        cluster_name,
-        node_role,
-        nodegroup_name,
-        subnets,
-        scaling_config=None,
-        disk_size=None,
-        instance_types=None,
-        ami_type=None,
-        remote_access=None,
-        labels=None,
-        taints=None,
-        tags=None,
-        client_request_token=None,
-        launch_template=None,
-        capacity_type=None,
-        version=None,
-        release_version=None,
-    ):
+        cluster_name: str,
+        node_role: str,
+        nodegroup_name: str,
+        subnets: List[str],
+        scaling_config: Optional[Dict[str, int]] = None,
+        disk_size: Optional[int] = None,
+        instance_types: Optional[List[str]] = None,
+        ami_type: Optional[str] = None,
+        remote_access: Optional[Dict[str, Any]] = None,
+        labels: Optional[Dict[str, str]] = None,
+        taints: Optional[List[Dict[str, str]]] = None,
+        tags: Optional[Dict[str, str]] = None,
+        client_request_token: Optional[str] = None,
+        launch_template: Optional[Dict[str, str]] = None,
+        capacity_type: Optional[str] = None,
+        version: Optional[str] = None,
+        release_version: Optional[str] = None,
+    ) -> Nodegroup:
         try:
             # Cluster exists.
             cluster = self.clusters[cluster_name]
@@ -452,7 +424,7 @@ class EKSBackend(BaseBackend):
                     nodegroupName=nodegroup_name, clusterName=cluster_name
                 ),
             )
-        if not cluster.isActive():
+        if not cluster.is_active:
             raise InvalidRequestException(
                 message=CLUSTER_NOT_READY_MSG.format(clusterName=cluster_name)
             )
@@ -460,7 +432,7 @@ class EKSBackend(BaseBackend):
             validate_launch_template_combination(disk_size, remote_access)
         validate_role_arn(node_role)
 
-        nodegroup = ManagedNodegroup(
+        nodegroup = Nodegroup(
             cluster_name=cluster_name,
             node_role=node_role,
             nodegroup_name=nodegroup_name,
@@ -487,7 +459,7 @@ class EKSBackend(BaseBackend):
         cluster.nodegroup_count += 1
         return nodegroup
 
-    def describe_cluster(self, name):
+    def describe_cluster(self, name: str) -> Cluster:
         try:
             # Cluster exists.
             return self.clusters[name]
@@ -501,7 +473,9 @@ class EKSBackend(BaseBackend):
                 message=CLUSTER_NOT_FOUND_MSG.format(clusterName=name),
             )
 
-    def describe_fargate_profile(self, cluster_name, fargate_profile_name):
+    def describe_fargate_profile(
+        self, cluster_name: str, fargate_profile_name: str
+    ) -> FargateProfile:
         try:
             # Cluster exists.
             cluster = self.clusters[cluster_name]
@@ -529,7 +503,7 @@ class EKSBackend(BaseBackend):
                 ),
             )
 
-    def describe_nodegroup(self, cluster_name, nodegroup_name):
+    def describe_nodegroup(self, cluster_name: str, nodegroup_name: str) -> Nodegroup:
         try:
             # Cluster exists.
             cluster = self.clusters[cluster_name]
@@ -555,7 +529,7 @@ class EKSBackend(BaseBackend):
                 message=NODEGROUP_NOT_FOUND_MSG.format(nodegroupName=nodegroup_name),
             )
 
-    def delete_cluster(self, name):
+    def delete_cluster(self, name: str) -> Cluster:
         try:
             # Cluster exists.
             validate_safe_to_delete(self.clusters[name])
@@ -573,7 +547,9 @@ class EKSBackend(BaseBackend):
         self.cluster_count -= 1
         return result
 
-    def delete_fargate_profile(self, cluster_name, fargate_profile_name):
+    def delete_fargate_profile(
+        self, cluster_name: str, fargate_profile_name: str
+    ) -> FargateProfile:
         try:
             # Cluster exists.
             cluster = self.clusters[cluster_name]
@@ -604,7 +580,7 @@ class EKSBackend(BaseBackend):
         cluster.fargate_profile_count -= 1
         return deleted_fargate_profile
 
-    def delete_nodegroup(self, cluster_name, nodegroup_name):
+    def delete_nodegroup(self, cluster_name: str, nodegroup_name: str) -> Nodegroup:
         try:
             # Cluster exists.
             cluster = self.clusters[cluster_name]
@@ -633,7 +609,7 @@ class EKSBackend(BaseBackend):
         cluster.nodegroup_count -= 1
         return result
 
-    def tag_resource(self, resource_arn, tags):
+    def tag_resource(self, resource_arn: str, tags: Dict[str, str]) -> None:
         """
         This function currently will tag an EKS cluster only.  It does not tag a managed node group
         """
@@ -654,9 +630,8 @@ class EKSBackend(BaseBackend):
                 message="An error occurred (NotFoundException) when calling the TagResource operation: Resource was not found",
             )
         cluster.tags.update(tags)
-        return ""
 
-    def untag_resource(self, resource_arn, tag_keys):
+    def untag_resource(self, resource_arn: str, tag_keys: List[str]) -> None:
         """
         This function currently will remove tags on an EKS cluster only.  It does not remove tags from a managed node group
         """
@@ -681,9 +656,8 @@ class EKSBackend(BaseBackend):
         for name in tag_keys:
             if name in cluster.tags:
                 del cluster.tags[name]
-        return ""
 
-    def list_tags_for_resource(self, resource_arn):
+    def list_tags_for_resource(self, resource_arn: str) -> Dict[str, str]:
         """
         This function currently will list tags on an EKS cluster only.  It does not list tags from a managed node group
         """
@@ -705,19 +679,61 @@ class EKSBackend(BaseBackend):
             )
         return cluster.tags
 
-    def list_clusters(self, max_results, next_token):
-        return paginated_list(self.clusters.keys(), max_results, next_token)
+    def list_clusters(
+        self, max_results: int, next_token: Optional[str]
+    ) -> Tuple[List[Cluster], Optional[Cluster]]:
+        return paginated_list(list(self.clusters.keys()), max_results, next_token)
 
-    def list_fargate_profiles(self, cluster_name, max_results, next_token):
+    def list_fargate_profiles(
+        self, cluster_name: str, max_results: int, next_token: Optional[str]
+    ) -> Tuple[List[FargateProfile], Optional[FargateProfile]]:
         cluster = self.clusters[cluster_name]
-        return paginated_list(cluster.fargate_profiles.keys(), max_results, next_token)
+        return paginated_list(
+            list(cluster.fargate_profiles.keys()), max_results, next_token
+        )
 
-    def list_nodegroups(self, cluster_name, max_results, next_token):
+    def list_nodegroups(
+        self, cluster_name: str, max_results: int, next_token: Optional[str]
+    ) -> Tuple[List[Nodegroup], Optional[Nodegroup]]:
         cluster = self.clusters[cluster_name]
-        return paginated_list(cluster.nodegroups.keys(), max_results, next_token)
+        return paginated_list(list(cluster.nodegroups.keys()), max_results, next_token)
+
+    def update_cluster_config(
+        self,
+        name: str,
+        resources_vpc_config: Dict[str, Any],
+        logging: Optional[Dict[str, Any]] = None,
+        client_request_token: Optional[str] = None,
+        kubernetes_network_config: Optional[Dict[str, str]] = None,
+        remote_network_config: Optional[Dict[str, List[Dict[str, List[str]]]]] = None,
+    ) -> Cluster:
+        cluster = self.clusters.get(name)
+        if cluster:
+            if resources_vpc_config:
+                self.clusters[name].resources_vpc_config = resources_vpc_config
+            if logging:
+                self.clusters[name].logging = logging
+            if client_request_token:
+                self.clusters[name].client_request_token = client_request_token
+            if kubernetes_network_config:
+                self.clusters[
+                    name
+                ].kubernetes_network_config = kubernetes_network_config
+            if remote_network_config:
+                self.clusters[name].remote_network_config = remote_network_config
+            return cluster
+        raise ResourceNotFoundException(
+            clusterName=name,
+            nodegroupName=None,
+            fargateProfileName=None,
+            addonName=None,
+            message=CLUSTER_NOT_FOUND_MSG.format(clusterName=name),
+        )
 
 
-def paginated_list(full_list, max_results, next_token):
+def paginated_list(
+    full_list: List[Any], max_results: int, next_token: Optional[str]
+) -> Tuple[List[Any], Optional[Any]]:
     """
     Returns a tuple containing a slice of the full list
     starting at next_token and ending with at most the
@@ -735,7 +751,7 @@ def paginated_list(full_list, max_results, next_token):
     return sorted_list[start:end], new_next
 
 
-def validate_safe_to_delete(cluster):
+def validate_safe_to_delete(cluster: Cluster) -> None:
     # A cluster which has nodegroups attached can not be deleted.
     if cluster.nodegroup_count:
         nodegroup_names = ",".join(list(cluster.nodegroups.keys()))
@@ -747,7 +763,9 @@ def validate_safe_to_delete(cluster):
         )
 
 
-def validate_launch_template_combination(disk_size, remote_access):
+def validate_launch_template_combination(
+    disk_size: Optional[int], remote_access: Optional[Dict[str, Any]]
+) -> None:
     if not (disk_size or remote_access):
         return
 
@@ -758,8 +776,8 @@ def validate_launch_template_combination(disk_size, remote_access):
     )
 
 
-def _validate_fargate_profile_selectors(selectors):
-    def raise_exception(message):
+def _validate_fargate_profile_selectors(selectors: List[Dict[str, Any]]) -> None:
+    def raise_exception(message: str) -> None:
         raise InvalidParameterException(
             clusterName=None,
             nodegroupName=None,
