@@ -40,6 +40,7 @@ class User(BaseModel):
         no_password_required: bool,
         passwords: Optional[List[str]] = None,
         authentication_type: Optional[str] = None,
+        tags: Optional[List[Dict[str, str]]] = None,
     ):
         self.id = user_id
         self.name = user_name
@@ -54,6 +55,7 @@ class User(BaseModel):
         self.region = region
         self.arn = f"arn:{get_partition(self.region)}:elasticache:{self.region}:{account_id}:user:{self.id}"
         self.authentication_type = authentication_type
+        self.tags = tags or []
 
     @property
     def authentication(self) -> dict[str, Any]:
@@ -64,6 +66,9 @@ class User(BaseModel):
             "PasswordCount": len(self.passwords) if self.passwords else None,
         }
 
+    def get_tags(self) -> List[Dict[str, str]]:
+        return self.tags
+
 
 class CacheCluster(BaseModel):
     def __init__(
@@ -595,7 +600,7 @@ class ElastiCacheBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
         self.arn_regex = re_compile(
-            r"^arn:aws:elasticache:.*:[0-9]*:(cluster|snapshot|subnetgroup|replicationgroup):.*$"
+            r"^arn:aws:elasticache:.*:[0-9]*:(cluster|snapshot|subnetgroup|replicationgroup|user):.*$"
         )
         self.users = dict()
         self.users["default"] = User(
@@ -621,6 +626,7 @@ class ElastiCacheBackend(BaseBackend):
         access_string: str,
         no_password_required: bool,
         authentication_type: str,  # contain it to the str in the enums TODO
+        tags: Optional[List[Dict[str, str]]] = None,
     ) -> User:
         if user_id in self.users:
             raise UserAlreadyExists
@@ -658,6 +664,7 @@ class ElastiCacheBackend(BaseBackend):
             access_string=access_string,
             no_password_required=no_password_required,
             authentication_type=authentication_type,
+            tags=tags,
         )
         self.users[user_id] = user
         return user
@@ -837,6 +844,9 @@ class ElastiCacheBackend(BaseBackend):
             elif resource_type == "replicationgroup":
                 if resource_name in self.replication_groups:
                     return self.replication_groups[resource_name].get_tags()
+            elif resource_type == "user":
+                if resource_name in self.users:
+                    return self.users[resource_name].get_tags()
             else:
                 return []
         else:
