@@ -2,6 +2,7 @@ from typing import Any, Dict, Iterator, List, Optional, Tuple
 
 from moto.acm.models import AWSCertificateManagerBackend, acm_backends
 from moto.appsync.models import AppSyncBackend, appsync_backends
+from moto.athena.models import athena_backends
 from moto.awslambda.models import LambdaBackend, lambda_backends
 from moto.backup.models import BackupBackend, backup_backends
 from moto.clouddirectory import CloudDirectoryBackend, clouddirectory_backends
@@ -14,6 +15,7 @@ from moto.connectcampaigns.models import (
 )
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.exceptions import RESTError
+from moto.directconnect.models import DirectConnectBackend, directconnect_backends
 from moto.dms.models import DatabaseMigrationServiceBackend, dms_backends
 from moto.dynamodb.models import DynamoDBBackend, dynamodb_backends
 from moto.ec2 import ec2_backends
@@ -73,6 +75,10 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
     def s3_backend(self) -> S3Backend:
         return s3_backends[self.account_id][self.partition]
 
+    @property
+    def directconnect_backend(self) -> DirectConnectBackend:
+        return directconnect_backends[self.account_id][self.region_name]
+
     @property
     def dms_backend(self) -> DatabaseMigrationServiceBackend:
         return dms_backends[self.account_id][self.region_name]
@@ -305,6 +311,37 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
 
                 yield {"ResourceARN": f"{api.arn}", "Tags": tags}
 
+        # Athena
+        if not resource_type_filters or "athena" in resource_type_filters:
+            athena_backend = athena_backends[self.account_id][self.region_name]
+
+            # Capacity Reservations
+            for capacity_reservation in athena_backend.capacity_reservations.values():
+                tags = athena_backend.tagger.list_tags_for_resource(
+                    capacity_reservation.name
+                )["Tags"]
+                if not tags or not tag_filter(tags):
+                    continue
+                yield {"ResourceARN": f"{capacity_reservation.name}", "Tags": tags}
+
+            # Workgroups
+            for work_group in athena_backend.work_groups.values():
+                tags = athena_backend.tagger.list_tags_for_resource(work_group.name)[
+                    "Tags"
+                ]
+                if not tags or not tag_filter(tags):
+                    continue
+                yield {"ResourceARN": f"{work_group.name}", "Tags": tags}
+
+            # Data Catalogs
+            for data_catalog in athena_backend.data_catalogs.values():
+                tags = athena_backend.tagger.list_tags_for_resource(data_catalog.name)[
+                    "Tags"
+                ]
+                if not tags or not tag_filter(tags):
+                    continue
+                yield {"ResourceARN": f"{data_catalog.name}", "Tags": tags}
+
         # Backup
         if not resource_type_filters or "backup" in resource_type_filters:
             for vault in self.backup_backend.vaults.values():
@@ -446,6 +483,33 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                         continue
                     yield {"ResourceARN": f"{campaign.arn}", "Tags": tags}
 
+        # Direct Connect
+        if self.directconnect_backend:
+            if not resource_type_filters or "directconnect" in resource_type_filters:
+                directconnect_backend = directconnect_backends[self.account_id][
+                    self.region_name
+                ]
+
+                # Connections
+                for connection in directconnect_backend.connections.values():
+                    tags = directconnect_backend.tagger.list_tags_for_resource(
+                        connection.connection_id
+                    )["Tags"]
+                    tags = format_tag_keys(tags, ["key", "value"])
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {"ResourceARN": f"{connection.connection_id}", "Tags": tags}
+
+                # LAGs
+                for lag in directconnect_backend.lags.values():
+                    tags = directconnect_backend.tagger.list_tags_for_resource(
+                        lag.lag_id
+                    )["Tags"]
+                    tags = format_tag_keys(tags, ["key", "value"])
+                    if not tags or not tag_filter(tags):
+                        continue
+                    yield {"ResourceARN": f"{lag.lag_id}", "Tags": tags}
+
         # DMS
         if not resource_type_filters or "dms:endpoint" in resource_type_filters:
             for endpoint in self.dms_backend.endpoints.values():
@@ -1278,7 +1342,7 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
         self, resource_arns: List[str], tags: Dict[str, str]
     ) -> Dict[str, Dict[str, Any]]:
         """
-        Only DynamoDB, Logs, RDS, and SageMaker resources are currently supported
+        Only DynamoDB, EFS, Lambda Logs, RDS, and SageMaker resources are currently supported
         """
         missing_resources = []
         missing_error: Dict[str, Any] = {
@@ -1315,12 +1379,44 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                 self.sagemaker_backend.add_tags(
                     arn, TaggingService.convert_dict_to_tags_input(tags)
                 )
+            elif arn.startswith(f"arn:{get_partition(self.region_name)}:lambda:"):
+                self.lambda_backend.tag_resource(arn, tags)
+            elif arn.startswith(
+                f"arn:{get_partition(self.region_name)}:elasticfilesystem:"
+            ):
+                resource_id = arn.split("/")[-1]
+                self.efs_backend.tag_resource(
+                    resource_id, TaggingService.convert_dict_to_tags_input(tags)
+                )
             else:
                 missing_resources.append(arn)
         return {arn: missing_error for arn in missing_resources}
 
-    # def untag_resources(self, resource_arn_list, tag_keys):
-    #     return failed_resources_map
+    def untag_resources(
+        self, resource_arn_list: List[str], tag_keys: List[str]
+    ) -> Dict[str, Dict[str, Any]]:
+        """
+        Only EFS and Lambda resources are currently supported
+        """
+        missing_resources = []
+        missing_error: Dict[str, Any] = {
+            "StatusCode": 404,
+            "ErrorCode": "InternalServiceException",
+            "ErrorMessage": "Service not yet supported",
+        }
+
+        for arn in resource_arn_list:
+            if arn.startswith(f"arn:{get_partition(self.region_name)}:lambda:"):
+                self.lambda_backend.untag_resource(arn, tag_keys)
+            elif arn.startswith(
+                f"arn:{get_partition(self.region_name)}:elasticfilesystem:"
+            ):
+                resource_id = arn.split("/")[-1]
+                self.efs_backend.untag_resource(resource_id, tag_keys)
+            else:
+                missing_resources.append(arn)
+
+        return {arn: missing_error for arn in missing_resources}
 
 
 resourcegroupstaggingapi_backends = BackendDict(
