@@ -1,19 +1,22 @@
-import boto3
-import pytest
-
-from botocore.exceptions import ClientError
+import copy
 from datetime import datetime, timedelta, timezone
-from dateutil.tz import tzutc
 from decimal import Decimal
-from freezegun import freeze_time
 from operator import itemgetter
+from unittest import SkipTest
 from uuid import uuid4
 
-from moto import mock_cloudwatch, mock_s3
+import boto3
+import pytest
+from botocore.exceptions import ClientError
+from dateutil.tz import tzutc
+from freezegun import freeze_time
+
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
+from moto.core.utils import utcnow
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_data_no_dimensions():
     conn = boto3.client("cloudwatch", region_name="us-east-1")
 
@@ -25,7 +28,44 @@ def test_put_metric_data_no_dimensions():
     assert {"Namespace": "tester", "MetricName": "metric", "Dimensions": []} in metrics
 
 
-@mock_cloudwatch
+@mock_aws
+def test_put_a_ton_of_metric_data():
+    """
+    A sufficiently large call with metric data triggers request compression
+    Moto should decompress the request if this is the case, and the request should succeed
+    """
+    if not settings.TEST_DECORATOR_MODE:
+        raise SkipTest("Can't test large requests in ServerMode")
+    cloudwatch = boto3.client("cloudwatch", "us-east-1")
+
+    metrics = []
+    metric_dimensions = [{"Name": "Environment", "Value": "env1"}]
+    metric_args = {"Unit": "Seconds", "MetricName": "TestCWMetrics"}
+
+    for type, licences in {
+        k: v
+        for k, v in {
+            "userTypes": [{"id": f"UserType{x}"} for x in range(0, 50)]
+        }.items()
+        if k in ["userTypes", "appBundles", "apps", "extensions", "portalCapabilities"]
+    }.items():
+        for licence in licences:
+            metrics.append(
+                {
+                    **metric_args,
+                    "Dimensions": [
+                        *metric_dimensions,
+                        {"Name": "Type", "Value": f"{type}/{licence['id']}"},
+                    ],
+                    "Value": 1,
+                }
+            )
+
+    cloudwatch.put_metric_data(Namespace="acme", MetricData=metrics)
+    # We don't really need any assertions - we just need to know that the call succeeds
+
+
+@mock_aws
 def test_put_metric_data_can_not_have_nan():
     client = boto3.client("cloudwatch", region_name="us-west-2")
     utc_now = datetime.now(tz=timezone.utc)
@@ -49,7 +89,7 @@ def test_put_metric_data_can_not_have_nan():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_data_can_not_have_value_and_values():
     client = boto3.client("cloudwatch", region_name="us-west-2")
     utc_now = datetime.now(tz=timezone.utc)
@@ -74,7 +114,7 @@ def test_put_metric_data_can_not_have_value_and_values():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_data_can_not_have_and_values_mismatched_counts():
     client = boto3.client("cloudwatch", region_name="us-west-2")
     utc_now = datetime.now(tz=timezone.utc)
@@ -99,7 +139,7 @@ def test_put_metric_data_can_not_have_and_values_mismatched_counts():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_data_values_and_counts():
     client = boto3.client("cloudwatch", region_name="us-west-2")
     utc_now = datetime.now(tz=timezone.utc)
@@ -130,7 +170,7 @@ def test_put_metric_data_values_and_counts():
     assert datapoint["Maximum"] == 10.0
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_data_values_without_counts():
     client = boto3.client("cloudwatch", region_name="us-west-2")
     utc_now = datetime.now(tz=timezone.utc)
@@ -160,7 +200,7 @@ def test_put_metric_data_values_without_counts():
     assert datapoint["Maximum"] == 23.45
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_data_value_and_statistics():
     conn = boto3.client("cloudwatch", region_name="us-east-1")
     with pytest.raises(ClientError) as exc:
@@ -184,7 +224,7 @@ def test_put_metric_data_value_and_statistics():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_data_with_statistics():
     conn = boto3.client("cloudwatch", region_name="us-east-1")
     utc_now = datetime.now(tz=timezone.utc)
@@ -260,7 +300,7 @@ def test_put_metric_data_with_statistics():
     assert datapoint["Average"] == 56.0
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_statistics():
     conn = boto3.client("cloudwatch", region_name="us-east-1")
     utc_now = datetime.now(tz=timezone.utc)
@@ -285,7 +325,7 @@ def test_get_metric_statistics():
     assert datapoint["Sum"] == 1.5
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_invalid_parameter_combination():
     conn = boto3.client("cloudwatch", region_name="us-east-1")
     utc_now = datetime.now(tz=timezone.utc)
@@ -310,7 +350,7 @@ def test_get_metric_invalid_parameter_combination():
     assert err["Message"] == "Must specify either Statistics or ExtendedStatistics"
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_statistics_dimensions():
     conn = boto3.client("cloudwatch", region_name="us-east-1")
     utc_now = datetime.now(tz=timezone.utc)
@@ -379,7 +419,7 @@ def test_get_metric_statistics_dimensions():
         assert datapoint["Average"] == params[2]
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_statistics_endtime_sooner_than_starttime():
     # given
     utc_now = datetime.now(tz=timezone.utc)
@@ -408,7 +448,7 @@ def test_get_metric_statistics_endtime_sooner_than_starttime():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_statistics_starttime_endtime_equals():
     # given
     utc_now = datetime.now(tz=timezone.utc)
@@ -437,7 +477,7 @@ def test_get_metric_statistics_starttime_endtime_equals():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_statistics_starttime_endtime_within_1_second():
     # given
     utc_now = datetime.now(tz=timezone.utc)
@@ -466,7 +506,7 @@ def test_get_metric_statistics_starttime_endtime_within_1_second():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_statistics_starttime_endtime_ignore_miliseconds():
     cloudwatch = boto3.client("cloudwatch", region_name="us-east-1")
     utc_now = datetime.now(tz=timezone.utc)
@@ -497,7 +537,7 @@ def test_get_metric_statistics_starttime_endtime_ignore_miliseconds():
     assert datapoint["Sum"] == 1.5
 
 
-@mock_cloudwatch
+@mock_aws
 def test_duplicate_put_metric_data():
     conn = boto3.client("cloudwatch", region_name="us-east-1")
     utc_now = datetime.now(tz=timezone.utc)
@@ -592,7 +632,7 @@ def test_duplicate_put_metric_data():
     ]
 
 
-@mock_cloudwatch
+@mock_aws
 @freeze_time("2020-02-10 18:44:05")
 def test_custom_timestamp():
     utc_now = datetime.now(tz=timezone.utc)
@@ -622,7 +662,7 @@ def test_custom_timestamp():
     assert resp["Datapoints"] == []
 
 
-@mock_cloudwatch
+@mock_aws
 def test_list_metrics():
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
     # Verify namespace has to exist
@@ -651,7 +691,7 @@ def test_list_metrics():
     assert res == []
 
 
-@mock_cloudwatch
+@mock_aws
 def test_list_metrics_paginated():
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
     # Verify that only a single page of metrics is returned
@@ -700,7 +740,7 @@ def test_list_metrics_paginated():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_list_metrics_without_value():
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
     # Create some metrics to filter on
@@ -719,7 +759,7 @@ def test_list_metrics_without_value():
     assert results[0]["Dimensions"] == [{"Name": "D1", "Value": "V1"}]
 
 
-@mock_cloudwatch
+@mock_aws
 def test_list_metrics_with_same_dimensions_different_metric_name():
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
 
@@ -790,7 +830,7 @@ def create_metrics_with_dimensions(cloudwatch, namespace, data_points=5):
         )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_for_multiple_metrics_w_same_dimensions():
     utc_now = datetime.now(tz=timezone.utc)
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
@@ -862,7 +902,7 @@ def test_get_metric_data_for_multiple_metrics_w_same_dimensions():
     assert res2["Values"] == [25.0]
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_within_timeframe():
     utc_now = datetime.now(tz=timezone.utc)
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
@@ -923,7 +963,7 @@ def test_get_metric_data_within_timeframe():
     assert [int(val) for val in max_["Values"]] == [100]
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_partially_within_timeframe():
     utc_now = datetime.now(tz=timezone.utc)
     yesterday = utc_now - timedelta(days=1)
@@ -1047,7 +1087,7 @@ def test_get_metric_data_partially_within_timeframe():
     assert response["MetricDataResults"][0]["Values"] == [10.0, 20.0, 10.0]
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_outside_timeframe():
     utc_now = datetime.now(tz=timezone.utc)
     last_week = utc_now - timedelta(days=7)
@@ -1088,7 +1128,7 @@ def test_get_metric_data_outside_timeframe():
     assert response["MetricDataResults"][0]["Values"] == []
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_for_multiple_metrics():
     utc_now = datetime.now(tz=timezone.utc)
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
@@ -1149,7 +1189,7 @@ def test_get_metric_data_for_multiple_metrics():
     assert res2["Values"] == [25.0]
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_for_dimensions():
     utc_now = datetime.now(tz=timezone.utc)
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
@@ -1257,7 +1297,7 @@ def test_get_metric_data_for_dimensions():
     assert res4["Values"] == [75.0]
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_for_unit():
     utc_now = datetime.now(tz=timezone.utc)
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
@@ -1329,7 +1369,7 @@ def test_get_metric_data_for_unit():
         assert metric_result_data[0]["Values"][0] == expected_value
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_endtime_sooner_than_starttime():
     # given
     utc_now = datetime.now(tz=timezone.utc)
@@ -1365,7 +1405,7 @@ def test_get_metric_data_endtime_sooner_than_starttime():
     assert err["Message"] == "The parameter EndTime must be greater than StartTime."
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_starttime_endtime_equals():
     # given
     utc_now = datetime.now(tz=timezone.utc)
@@ -1401,7 +1441,7 @@ def test_get_metric_data_starttime_endtime_equals():
     assert err["Message"] == "The parameter StartTime must not equal parameter EndTime."
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_starttime_endtime_within_1_second():
     # given
     utc_now = datetime.now(tz=timezone.utc)
@@ -1439,7 +1479,7 @@ def test_get_metric_data_starttime_endtime_within_1_second():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_starttime_endtime_ignore_miliseconds():
     utc_now = datetime.now(tz=timezone.utc).replace(microsecond=200 * 1000)
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
@@ -1480,16 +1520,15 @@ def test_get_metric_data_starttime_endtime_ignore_miliseconds():
     assert response["MetricDataResults"][0]["Values"][0] == 1.0
 
 
-@mock_cloudwatch
-@mock_s3
+@mock_aws
 def test_cloudwatch_return_s3_metrics():
     utc_now = datetime.now(tz=timezone.utc)
     bucket_name = "examplebucket"
     cloudwatch = boto3.client("cloudwatch", "eu-west-3")
 
     # given
-    s3 = boto3.resource("s3")
-    s3_client = boto3.client("s3")
+    s3 = boto3.resource("s3", "eu-west-3")
+    s3_client = boto3.client("s3", "eu-west-3")
     bucket = s3.Bucket(bucket_name)
     bucket.create(CreateBucketConfiguration={"LocationConstraint": "eu-west-3"})
     bucket.put_object(Body=b"ABCD", Key="file.txt")
@@ -1565,7 +1604,7 @@ def test_cloudwatch_return_s3_metrics():
     s3_client.delete_bucket(Bucket=bucket_name)
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_alarm():
     # given
     region_name = "eu-central-1"
@@ -1633,7 +1672,7 @@ def test_put_metric_alarm():
     assert alarm["TreatMissingData"] == "notBreaching"
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_alarm_with_percentile():
     # given
     region_name = "eu-central-1"
@@ -1695,7 +1734,7 @@ def test_put_metric_alarm_with_percentile():
     assert alarm["EvaluateLowSampleCountPercentile"] == "ignore"
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_alarm_with_anomaly_detection():
     # given
     region_name = "eu-central-1"
@@ -1754,7 +1793,7 @@ def test_put_metric_alarm_with_anomaly_detection():
     assert alarm["ThresholdMetricId"] == "t1"
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_alarm_error_extended_statistic():
     # given
     region_name = "eu-central-1"
@@ -1793,7 +1832,7 @@ def test_put_metric_alarm_error_extended_statistic():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_put_metric_alarm_error_evaluate_low_sample_count_percentile():
     # given
     region_name = "eu-central-1"
@@ -1834,7 +1873,7 @@ def test_put_metric_alarm_error_evaluate_low_sample_count_percentile():
     )
 
 
-@mock_cloudwatch
+@mock_aws
 def test_get_metric_data_with_custom_label():
     utc_now = datetime.now(tz=timezone.utc)
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
@@ -1903,3 +1942,59 @@ def test_get_metric_data_with_custom_label():
         )
         assert len(metric_result_data) == 1
         assert metric_result_data[0]["Label"] == expected_value
+
+
+@mock_aws
+def test_get_metric_data_queries():
+    """
+    verify that >= 10 queries can still be parsed
+    there was an error with the order of parsing items, leading to IndexError
+    """
+    now = utcnow().replace(microsecond=0)
+    start_time = now - timedelta(minutes=10)
+    end_time = now + timedelta(minutes=5)
+    original_query = {
+        "MetricStat": {
+            "Metric": {
+                "Namespace": "AWS/RDS",
+                "MetricName": "CPUUtilization",
+                "Dimensions": [{"Name": "DBInstanceIdentifier", "Value": ""}],
+            },
+            "Period": 1,
+            "Stat": "Average",
+            "Unit": "Percent",
+        },
+    }
+
+    queries = []
+    for i in range(0, 20):
+        query = copy.deepcopy(original_query)
+        query["Id"] = f"q{i}"
+        query["MetricStat"]["Metric"]["Dimensions"][0]["Value"] = f"id-{i}"
+        queries.append(query)
+
+    assert len(queries) == 20
+    response = boto3.client("cloudwatch", "eu-west-1").get_metric_data(
+        StartTime=start_time, EndTime=end_time, MetricDataQueries=queries
+    )
+
+    # we expect twenty results
+    assert len(response["MetricDataResults"]) == 20
+
+
+@mock_aws
+def test_put_dashboard_invalid_json_raises_error():
+    client = boto3.client("cloudwatch", "eu-west-1")
+    with pytest.raises(ClientError) as exc:
+        client.put_dashboard(DashboardName="test", DashboardBody='{"InvalidJson": true')
+    error = exc.value.response["Error"]
+    assert error["Code"] == "InvalidParameterInput"
+
+
+@mock_aws
+def test_delete_dashboard_with_empty_list_raises_error():
+    client = boto3.client("cloudwatch", "eu-west-1")
+    with pytest.raises(ClientError) as exc:
+        client.delete_dashboards(DashboardNames=[])
+    error = exc.value.response["Error"]
+    assert error["Code"] == "InvalidParameterValue"
