@@ -2,13 +2,13 @@ from uuid import uuid1
 
 import boto3
 import pytest
-from botocore.exceptions import ClientError, ParamValidationError
+from botocore.exceptions import ClientError
 
-from moto import mock_codebuild
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_create_project_s3_artifacts():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -37,6 +37,7 @@ def test_codebuild_create_project_s3_artifacts():
         artifacts=artifacts,
         environment=environment,
         serviceRole=service_role,
+        tags=[{"key": "k1", "value": "v1"}],
     )["project"]
 
     assert "serviceRole" in project
@@ -51,8 +52,10 @@ def test_codebuild_create_project_s3_artifacts():
     assert project["source"] == {"location": "bucketname/path/file.zip", "type": "S3"}
     assert project["artifacts"] == {"location": "bucketname", "type": "S3"}
 
+    assert project["tags"] == [{"key": "k1", "value": "v1"}]
 
-@mock_codebuild
+
+@mock_aws
 def test_codebuild_create_project_no_artifacts():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -94,7 +97,7 @@ def test_codebuild_create_project_no_artifacts():
     assert project["artifacts"] == {"type": "NO_ARTIFACTS"}
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_create_project_with_invalid_inputs():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -126,7 +129,7 @@ def test_codebuild_create_project_with_invalid_inputs():
     assert err.value.response["Error"]["Code"] == "InvalidInputException"
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_create_project_when_exists():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -164,7 +167,7 @@ def test_codebuild_create_project_when_exists():
     assert err.value.response["Error"]["Code"] == "ResourceAlreadyExistsException"
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_list_projects():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -205,7 +208,7 @@ def test_codebuild_list_projects():
     assert projects["projects"] == ["project1", "project2"]
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_list_builds_for_project_no_history():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -237,7 +240,7 @@ def test_codebuild_list_builds_for_project_no_history():
     assert history["ids"] == []
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_list_builds_for_project_with_history():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -269,43 +272,7 @@ def test_codebuild_list_builds_for_project_with_history():
     assert len(response["ids"]) == 1
 
 
-# project never started
-@mock_codebuild
-def test_codebuild_get_batch_builds_for_project_no_history():
-    client = boto3.client("codebuild", region_name="eu-central-1")
-
-    name = "some_project"
-    source = dict()
-    source["type"] = "S3"
-    # repository location for S3
-    source["location"] = "bucketname/path/file.zip"
-    artifacts = {"type": "NO_ARTIFACTS"}
-
-    environment = dict()
-    environment["type"] = "LINUX_CONTAINER"
-    environment["image"] = "contents_not_validated"
-    environment["computeType"] = "BUILD_GENERAL1_SMALL"
-    service_role = (
-        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
-    )
-
-    client.create_project(
-        name=name,
-        source=source,
-        artifacts=artifacts,
-        environment=environment,
-        serviceRole=service_role,
-    )
-
-    response = client.list_builds_for_project(projectName=name)
-    assert response["ids"] == []
-
-    with pytest.raises(ParamValidationError) as err:
-        client.batch_get_builds(ids=response["ids"])
-    assert err.typename == "ParamValidationError"
-
-
-@mock_codebuild
+@mock_aws
 def test_codebuild_start_build_no_project():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -316,7 +283,7 @@ def test_codebuild_start_build_no_project():
     assert err.value.response["Error"]["Code"] == "ResourceNotFoundException"
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_start_build_no_overrides():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -347,7 +314,7 @@ def test_codebuild_start_build_no_overrides():
     assert response["build"]["sourceVersion"] == "refs/heads/main"
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_start_build_multiple_times():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -381,7 +348,7 @@ def test_codebuild_start_build_multiple_times():
     assert len(client.list_builds()["ids"]) == 3
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_start_build_with_overrides():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -419,7 +386,7 @@ def test_codebuild_start_build_with_overrides():
     assert response["build"]["sourceVersion"] == "fix/testing"
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_batch_get_builds_1_project():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -457,7 +424,7 @@ def test_codebuild_batch_get_builds_1_project():
     assert len(response["builds"][0]["phases"]) == 11
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_batch_get_builds_2_projects():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -506,7 +473,7 @@ def test_codebuild_batch_get_builds_2_projects():
     assert "project-2" in metadata[1]["id"]
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_batch_get_builds_invalid_build_id():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -515,16 +482,7 @@ def test_codebuild_batch_get_builds_invalid_build_id():
     assert err.value.response["Error"]["Code"] == "InvalidInputException"
 
 
-@mock_codebuild
-def test_codebuild_batch_get_builds_empty_build_id():
-    client = boto3.client("codebuild", region_name="eu-central-1")
-
-    with pytest.raises(ParamValidationError) as err:
-        client.batch_get_builds(ids=[])
-    assert err.typename == "ParamValidationError"
-
-
-@mock_codebuild
+@mock_aws
 def test_codebuild_delete_project():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -562,7 +520,7 @@ def test_codebuild_delete_project():
     assert err.value.response["Error"]["Code"] == "ResourceNotFoundException"
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_stop_build():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -596,7 +554,7 @@ def test_codebuild_stop_build():
     assert response["build"]["buildStatus"] == "STOPPED"
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_stop_build_no_build():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
@@ -605,10 +563,49 @@ def test_codebuild_stop_build_no_build():
     assert err.value.response["Error"]["Code"] == "ResourceNotFoundException"
 
 
-@mock_codebuild
+@mock_aws
 def test_codebuild_stop_build_bad_uid():
     client = boto3.client("codebuild", region_name="eu-central-1")
 
     with pytest.raises(client.exceptions.InvalidInputException) as err:
         client.stop_build(id=f"some_project{uuid1()}")
     assert err.value.response["Error"]["Code"] == "InvalidInputException"
+
+
+@mock_aws
+def test_codebuild_batch_get_projects():
+    client = boto3.client("codebuild", region_name="eu-central-1")
+
+    name = "some_project"
+    source = dict()
+    source["type"] = "S3"
+    # repository location for S3
+    source["location"] = "bucketname/path/file.zip"
+    artifacts = {"type": "NO_ARTIFACTS"}
+
+    environment = dict()
+    environment["type"] = "LINUX_CONTAINER"
+    environment["image"] = "contents_not_validated"
+    environment["computeType"] = "BUILD_GENERAL1_SMALL"
+    service_role = (
+        f"arn:aws:iam::{ACCOUNT_ID}:role/service-role/my-codebuild-service-role"
+    )
+
+    project_arn = client.create_project(
+        name=name,
+        source=source,
+        artifacts=artifacts,
+        environment=environment,
+        serviceRole=service_role,
+    )["project"]["arn"]
+
+    projects_batch = client.batch_get_projects(names=[name])["projects"]
+    assert len(projects_batch) == 1
+    assert projects_batch[0]["name"] == name
+    assert projects_batch[0]["arn"] == project_arn
+
+    # Assert we can also use the ARN
+    projects_batch = client.batch_get_projects(names=[project_arn])["projects"]
+    assert len(projects_batch) == 1
+    assert projects_batch[0]["name"] == name
+    assert projects_batch[0]["arn"] == project_arn
