@@ -64,14 +64,12 @@ def test_create_load_balancer(zones, region_name):
         "LoadBalancerPort": 80,
         "InstanceProtocol": "TCP",
         "InstancePort": 8080,
-        "SSLCertificateId": "None",
     }
     assert http == {
         "Protocol": "HTTP",
         "LoadBalancerPort": 81,
         "InstanceProtocol": "HTTP",
         "InstancePort": 9000,
-        "SSLCertificateId": "None",
     }
 
 
@@ -176,7 +174,7 @@ def test_create_load_balancer_with_invalid_certificate():
             AvailabilityZones=["us-east-2a"],
         )
     err = exc.value.response["Error"]
-    assert err["Code"] == "CertificateNotFoundException"
+    assert err["Code"] == "CertificateNotFound"
 
 
 @mock_aws
@@ -400,7 +398,7 @@ def test_create_lb_listener_with_ssl_certificate_from_acm():
     assert len(listeners) == 2
 
     assert listeners[0]["Listener"]["Protocol"] == "HTTP"
-    assert listeners[0]["Listener"]["SSLCertificateId"] == "None"
+    assert listeners[0]["Listener"].get("SSLCertificateId") is None
 
     assert listeners[1]["Listener"]["Protocol"] == "TCP"
     assert listeners[1]["Listener"]["SSLCertificateId"] == certificate_arn
@@ -440,7 +438,7 @@ def test_create_lb_listener_with_ssl_certificate_from_iam():
     assert len(listeners) == 2
 
     assert listeners[0]["Listener"]["Protocol"] == "HTTP"
-    assert listeners[0]["Listener"]["SSLCertificateId"] == "None"
+    assert listeners[0]["Listener"].get("SSLCertificateId") is None
 
     assert listeners[1]["Listener"]["Protocol"] == "TCP"
     assert listeners[1]["Listener"]["SSLCertificateId"] == certificate_arn
@@ -469,7 +467,7 @@ def test_create_lb_listener_with_invalid_ssl_certificate():
             ],
         )
     err = exc.value.response["Error"]
-    assert err["Code"] == "CertificateNotFoundException"
+    assert err["Code"] == "CertificateNotFound"
 
 
 @mock_aws
@@ -503,7 +501,7 @@ def test_set_sslcertificate():
 
     listener = elb["ListenerDescriptions"][0]["Listener"]
     assert listener["LoadBalancerPort"] == 80
-    assert listener["SSLCertificateId"] == "None"
+    assert listener.get("SSLCertificateId") is None
 
     listener = elb["ListenerDescriptions"][1]["Listener"]
     assert listener["LoadBalancerPort"] == 81
